timespantools.TimespanTimespanTimeRelation
==========================================

.. abjad-lineage:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation

.. autoclass:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.get_counttime_components
      ~abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.get_offset_indices
      ~abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.inequality
      ~abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.is_fully_loaded
      ~abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.is_fully_unloaded
      ~abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.timespan_1
      ~abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.timespan_2
      ~abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.__call__
      ~abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.__eq__
      ~abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.__format__
      ~abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.__makenew__
      ~abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.__ne__
      ~abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.__repr__

Bases
-----

- :py:class:`timespantools.TimeRelation <abjad.tools.timespantools.TimeRelation.TimeRelation>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.inequality
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.is_fully_loaded
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.is_fully_unloaded
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.timespan_1
   :noindex:

.. autoattribute:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.timespan_2
   :noindex:

Methods
-------

.. automethod:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.get_counttime_components
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.get_offset_indices
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.__call__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.__eq__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.__format__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.__makenew__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.__ne__
   :noindex:

.. automethod:: abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation.__repr__
   :noindex:
